@@ -2,10 +2,6 @@
 Aggregates from the different modules
 """
 
-# pylint: disable=import-outside-toplevel
-
-from dotenv import load_dotenv
-
 # Re-export functions :
 from aikido_zen.context.users import set_user
 from aikido_zen.middleware import should_block_request
@@ -20,8 +16,6 @@ from aikido_zen.background_process import start_background_process
 from aikido_zen.config import PKG_VERSION
 from aikido_zen.helpers.aikido_disabled_flag_active import aikido_disabled_flag_active
 
-load_dotenv()
-
 
 def protect(mode="daemon"):
     """
@@ -47,11 +41,8 @@ def protect(mode="daemon"):
     import aikido_zen.sources.flask
     import aikido_zen.sources.quart
     import aikido_zen.sources.starlette
-    import aikido_zen.sources.xml
-    import aikido_zen.sources.lxml
-
-    import aikido_zen.sources.gunicorn
-    import aikido_zen.sources.uwsgi
+    import aikido_zen.sources.xml_sources.xml
+    import aikido_zen.sources.xml_sources.lxml
 
     # Import DB Sinks
     import aikido_zen.sinks.pymysql
@@ -60,6 +51,8 @@ def protect(mode="daemon"):
     import aikido_zen.sinks.psycopg2
     import aikido_zen.sinks.psycopg
     import aikido_zen.sinks.asyncpg
+    import aikido_zen.sinks.clickhouse_driver
+
     import aikido_zen.sinks.builtins
     import aikido_zen.sinks.os
     import aikido_zen.sinks.shutil
@@ -71,4 +64,7 @@ def protect(mode="daemon"):
     import aikido_zen.sinks.os_system
     import aikido_zen.sinks.subprocess
 
+    # Import AI sinks
+    import aikido_zen.sinks.openai
+
     logger.info("Zen by Aikido v%s starting.", PKG_VERSION)
